LoadMoreController constructor
const
LoadMoreController({})
if the autoLoad argument be true:
onLoadwill be called when viewport not filledonLoadwill be called when the sliver reach the cacheExtent of the viewport other arguments work like those of CupertinoSliverRefreshControl
Implementation
const LoadMoreController({
super.key,
required this.onLoad,
this.refreshTriggerPullDistance = 76,
this.refreshIndicatorExtent = 56,
this.builder = CupertinoSliverRefreshControl.buildRefreshIndicator,
this.autoLoad = false,
}) : assert(refreshTriggerPullDistance > 0.0),
assert(refreshIndicatorExtent >= 0.0),
assert(
refreshTriggerPullDistance >= refreshIndicatorExtent,
'The refresh indicator cannot take more space in its final state '
'than the amount initially created by overscrolling.',
);